@@ -1,15 +1,15 @@
 package URI::ftps;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use strict;
 use warnings;
 
 use base qw(URI::_server URI::_userpass);
 
-sub default_port { 21 }
+sub default_port { 990 }
 
-sub path { shift->path_query(@_) }  # XXX
+sub path { shift->path_query(@_) }  
 
 
 1;
